@@ -23,24 +23,14 @@ def create_bigquery_client(info=None, credential_filepath=None, project_id=None)
     else:
         if credential_filepath:
             cred = service_account.Credentials.from_service_account_file(credential_filepath)
-        '''
-        else:
-            cred = service_account.Credentials.from_service_account_file(
-                                                            lib_conf.BIGQUERY_SERVICE_CREDENTIAL_PATH,
-                                                            scopes=["https://www.googleapis.com/auth/cloud-platform", 
-                                                                    "https://www.googleapis.com/auth/bigquery.insertdata"
-                                                                    ]
-                                                            )
-        '''
+        
             
-    #client = bigquery.Client(project=lib_conf.BIGQUERY_GCLOUD_PROJECT_ID, credentials=cred, location=lib_conf.BIGQUERY_GCLOUD_LOCATION)
-    #client = bigquery.Client(project=lib_conf.BIGQUERY_GCLOUD_PROJECT_ID, credentials=cred)
     if cred:
         client = bigquery.Client(project=project_id, credentials=cred)
         
         return client 
 
-def create_dataset_reference(dataset_name, project_id):
+def create_dataset_reference(project_id, dataset_name):
     #dataset_ref = DatasetReference(lib_conf.BIGQUERY_GCLOUD_PROJECT_ID, dataset_name)
     dataset_ref = DatasetReference(project_id, dataset_name)
     return dataset_ref
@@ -67,7 +57,11 @@ def create_table_from_template(dataset_name, table_name, table_scheme, table_nam
     if bigquery_client is None:
         bigquery_client   = create_bigquery_client()
     
-    dataset_ref = create_dataset_reference(dataset_name)
+    project_id = bigquery_client.project
+    
+    logger.debug('create_table_from_template: project_id=%s', project_id)
+    
+    dataset_ref = create_dataset_reference(project_id, dataset_name)
     
     if if_dataset_exists(bigquery_client, dataset_ref) is False:
         logger.debug('dataset(%s) is not exist, thus going to create it', dataset_name)
@@ -345,10 +339,10 @@ def wait_for_job(job):
 
 def execute_query(bigquery_client, query):
     job_id = str(uuid.uuid4())
-    
-    query_job = bigquery_client.query(query, job_id=job_id)
-    
-    return query_job.result()
+    if bigquery_client:
+        query_job = bigquery_client.query(query, job_id=job_id)
+        
+        return query_job.result()
         
 def process_job_result_into_category_and_count(job_result_rows):
     row_list = []
